@@ -92,7 +92,7 @@ namespace Imendio.Blam {
 
 	    try {
 		reader = new XmlTextReader (file);
-	    } catch (Exception e) {
+	    } catch (Exception) {
 		reader = new XmlTextReader (GetTempFile (file));
 	    }
 	    
@@ -124,7 +124,7 @@ namespace Imendio.Blam {
 		    Stream writer = new FileStream (tmpFile, FileMode.Create);
 		    serializer.Serialize (writer, this);
 		    writer.Close();
-		} catch (Exception e) {
+		} catch (Exception) {
 		    System.Console.WriteLine ("Failed to save to temporary file");
 		    return;
 		}
@@ -191,23 +191,48 @@ namespace Imendio.Blam {
 	    thread.Start ();
 	}
 
+	private void QueueChannelRefresh (Channel channel)
+	{
+	    mQueue.Enqueue (channel);
+	    EmitChannelRefreshStarted (channel);
+	}
+
+	private void StartRefreshThreads (int maxNrOfThreads)
+	{
+	    // Only start a maximum of five threads
+	    for (int i = 0; i < 5 && i < maxNrOfThreads; ++i) { 
+		Thread thread = new Thread (new ThreadStart (UpdateThread));
+		mRunningList.Add (thread);
+		thread.Start ();
+	    }
+	}
+
 	public void RefreshAll ()
 	{
 	    int nrOfChannels = 0;
 	    
 	    foreach (Channel channel in mChannels) {
-		mQueue.Enqueue (channel);
-		EmitChannelRefreshStarted (channel);
-
+		QueueChannelRefresh (channel);
 		nrOfChannels++;
 	    }
 
-	    // Only start a maximum of five threads
-	    for (int i = 0; i < 5 && i < nrOfChannels; ++i) { 
-		Thread thread = new Thread (new ThreadStart (UpdateThread));
-		mRunningList.Add (thread);
-		thread.Start ();
+	    StartRefreshThreads (nrOfChannels);
+	}
+
+	public void RefreshAll (int refreshRate) 
+	{
+	    int nrOfChannels = 0;
+
+	    foreach (Channel channel in mChannels) {
+		TimeSpan span = DateTime.Now.Subtract (channel.LastRefreshed);
+		
+		if (span.TotalSeconds >= refreshRate * 60) {
+		    QueueChannelRefresh (channel);
+		    nrOfChannels++;
+		}
 	    }
+	    
+	    StartRefreshThreads (nrOfChannels);
 	}
 	
 	/* Used to cross-mark as read */
@@ -232,7 +257,7 @@ namespace Imendio.Blam {
 		    }	
 
 		    new MainloopEmitter (this.ChannelRefreshFinished, channel).Emit ();
-		} catch (InvalidOperationException exception) {
+		} catch (InvalidOperationException) {
 		    break;
 		}
 	    }
